@@ -1,5 +1,5 @@
 package Selenium::Remote::RemoteConnection;
-$Selenium::Remote::RemoteConnection::VERSION = '0.27';
+$Selenium::Remote::RemoteConnection::VERSION = '1.00';
 #ABSTRACT: Connect to a selenium server
 
 use Moo;
@@ -7,7 +7,6 @@ use Try::Tiny;
 use LWP::UserAgent;
 use HTTP::Headers;
 use HTTP::Request;
-use Net::Ping;
 use Carp qw(croak);
 use JSON;
 use Data::Dumper;
@@ -36,11 +35,12 @@ has 'error_handler' => (
     builder => sub { return Selenium::Remote::ErrorHandler->new; }
 );
 
-
+with 'Selenium::Remote::Driver::CanSetWebdriverContext';
 
 sub check_status {
     my $self = shift;
     my $status;
+
     try {
         $status = $self->request({method => 'GET', url => 'status'});
     }
@@ -59,9 +59,6 @@ sub check_status {
     }
 }
 
-
-
-# This request method is tailored for Selenium RC server
 sub request {
     my ($self,$resource,$params,$dont_process_response) = @_;
     my $method =        $resource->{method};
@@ -87,7 +84,8 @@ sub request {
             "http://"
           . $self->remote_server_addr . ":"
           . $self->port
-          . "/wd/hub/$url";
+          . $self->wd_context_prefix
+          . "/$url";
     }
 
     if ((defined $params) && $params ne '') {
@@ -185,7 +183,7 @@ Selenium::Remote::RemoteConnection - Connect to a selenium server
 
 =head1 VERSION
 
-version 0.27
+version 1.00
 
 =head1 SEE ALSO
 
